pub struct MockOrganizationUsersApi {
OrganizationUsersApi_expectations: MockOrganizationUsersApi_OrganizationUsersApi,
}Fields
OrganizationUsersApi_expectations: MockOrganizationUsersApi_OrganizationUsersApiImplementations
Sourceimpl MockOrganizationUsersApi
impl MockOrganizationUsersApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockOrganizationUsersApi
impl MockOrganizationUsersApi
Sourcepub fn expect_accept(&mut self) -> &mut Expectation
pub fn expect_accept(&mut self) -> &mut Expectation
Create an Expectation for mocking the accept method
Sourcepub fn expect_accept_init(&mut self) -> &mut Expectation
pub fn expect_accept_init(&mut self) -> &mut Expectation
Create an Expectation for mocking the accept_init method
Sourcepub fn expect_automatically_confirm_organization_user(
&mut self,
) -> &mut Expectation
pub fn expect_automatically_confirm_organization_user( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the automatically_confirm_organization_user method
Sourcepub fn expect_bulk_automatically_confirm_organization_users(
&mut self,
) -> &mut Expectation
pub fn expect_bulk_automatically_confirm_organization_users( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the bulk_automatically_confirm_organization_users method
Sourcepub fn expect_bulk_confirm(&mut self) -> &mut Expectation
pub fn expect_bulk_confirm(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_confirm method
Sourcepub fn expect_bulk_delete_account(&mut self) -> &mut Expectation
pub fn expect_bulk_delete_account(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_delete_account method
Sourcepub fn expect_bulk_enable_secrets_manager(&mut self) -> &mut Expectation
pub fn expect_bulk_enable_secrets_manager(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_enable_secrets_manager method
Sourcepub fn expect_bulk_reinvite(&mut self) -> &mut Expectation
pub fn expect_bulk_reinvite(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_reinvite method
Sourcepub fn expect_bulk_remove(&mut self) -> &mut Expectation
pub fn expect_bulk_remove(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_remove method
Sourcepub fn expect_bulk_restore(&mut self) -> &mut Expectation
pub fn expect_bulk_restore(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_restore method
Sourcepub fn expect_bulk_revoke(&mut self) -> &mut Expectation
pub fn expect_bulk_revoke(&mut self) -> &mut Expectation
Create an Expectation for mocking the bulk_revoke method
Sourcepub fn expect_confirm(&mut self) -> &mut Expectation
pub fn expect_confirm(&mut self) -> &mut Expectation
Create an Expectation for mocking the confirm method
Sourcepub fn expect_delete_account(&mut self) -> &mut Expectation
pub fn expect_delete_account(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete_account method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_account_recovery_details(&mut self) -> &mut Expectation
pub fn expect_get_account_recovery_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_account_recovery_details method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_mini_details(&mut self) -> &mut Expectation
pub fn expect_get_mini_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_mini_details method
Sourcepub fn expect_get_pending_auto_confirm_users(&mut self) -> &mut Expectation
pub fn expect_get_pending_auto_confirm_users(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_pending_auto_confirm_users method
Sourcepub fn expect_get_reset_password_details(&mut self) -> &mut Expectation
pub fn expect_get_reset_password_details(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_reset_password_details method
Sourcepub fn expect_invite(&mut self) -> &mut Expectation
pub fn expect_invite(&mut self) -> &mut Expectation
Create an Expectation for mocking the invite method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_put_recover_account(&mut self) -> &mut Expectation
pub fn expect_put_recover_account(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_recover_account method
Sourcepub fn expect_put_reset_password(&mut self) -> &mut Expectation
pub fn expect_put_reset_password(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_reset_password method
Sourcepub fn expect_put_reset_password_enrollment(&mut self) -> &mut Expectation
pub fn expect_put_reset_password_enrollment(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_reset_password_enrollment method
Sourcepub fn expect_reinvite(&mut self) -> &mut Expectation
pub fn expect_reinvite(&mut self) -> &mut Expectation
Create an Expectation for mocking the reinvite method
Sourcepub fn expect_remove(&mut self) -> &mut Expectation
pub fn expect_remove(&mut self) -> &mut Expectation
Create an Expectation for mocking the remove method
Sourcepub fn expect_restore_async_v_next(&mut self) -> &mut Expectation
pub fn expect_restore_async_v_next(&mut self) -> &mut Expectation
Create an Expectation for mocking the restore_async_v_next method
Sourcepub fn expect_revoke(&mut self) -> &mut Expectation
pub fn expect_revoke(&mut self) -> &mut Expectation
Create an Expectation for mocking the revoke method
Sourcepub fn expect_revoke_self(&mut self) -> &mut Expectation
pub fn expect_revoke_self(&mut self) -> &mut Expectation
Create an Expectation for mocking the revoke_self method
Sourcepub fn expect_user_public_keys(&mut self) -> &mut Expectation
pub fn expect_user_public_keys(&mut self) -> &mut Expectation
Create an Expectation for mocking the user_public_keys method